periodic_sync_strategy library
Classes
- PeriodicSyncStrategy
- A reusable periodic synchronization strategy that separates technical implementation from business logic.
Typedefs
-
BuildSyncFilterCallback
= Future<
JsonMap?> Function(String repositoryName) - Callback for building sync filter parameters for a repository.
-
FetchEventsCallback
= Future<
List< Function(String repositoryName)JsonMap> > - Callback for fetching remote events for a repository.
-
PingCallback
= Future<
bool> Function() - Callback for checking connection health.
-
PushEventsCallback
= Future<
bool> Function(String repositoryName, LocalFirstEvents events) - Callback for pushing local events to remote server.
-
SaveSyncStateCallback
= Future<
void> Function(String repositoryName, List<JsonMap> events) - Callback for saving sync state after events are successfully applied.